@@ -11,6 +11,7 @@ from functools import partial
 import os
 import subprocess as sp
 import sys
+import typing as tp
 
 from .log import simple_log, fatal
 
@@ -55,10 +56,10 @@ class ChildrenManager:
             log("All workers completed successfully")
 
 
-def start_ddp_workers(package, main, argv):
+def start_ddp_workers(main, argv, num_workers: tp.Optional[int] = None):
     import torch as th
 
-    world_size = th.cuda.device_count()
+    world_size = num_workers or th.cuda.device_count()
     if not world_size:
         fatal(
             "DDP is only available on GPU. Make sure GPUs are properly configured with cuda.")
@@ -71,12 +72,13 @@ def start_ddp_workers(package, main, argv):
     log(f"Starting {world_size} worker processes for DDP.")
     with ChildrenManager() as manager:
         for rank in range(world_size):
-            kwargs = {}
+            kwargs: tp.Dict[str, tp.Any] = {}
             env = dict(os.environ)
             env['RANK'] = str(rank)
             env['WORLD_SIZE'] = str(world_size)
             env['MASTER_ADDR'] = '127.0.0.1'
-            args = ["-m", "dora", "-P", package, "run", "--"]
+            args = ["-m", "dora", "-P", main.package, "--main_module", main.main_module,
+                    "run", "--"]
             args += argv
             if rank > 0:
                 kwargs['stdin'] = sp.DEVNULL
