@@ -17,7 +17,6 @@ import fnmatch
 from functools import partial
 import os
 from pathlib import Path
-import pkgutil
 import typing as tp
 import shutil
 import sys
@@ -89,25 +88,33 @@ class RunGridArgs:
     _from_commandline: bool = False
 
 
-def _get_explore(args):
+def _get_explore(args, main):
     # Finds the explorer.
-    package = args.package
-    root_name = package + ".grids"
-    grids = import_or_fatal(root_name)
+    grid_package = main.dora.grid_package
+    if grid_package is None:
+        grid_package = main.package + ".grids"
 
-    grid_file = Path(grids.__file__).parent / f'{args.grid}.py'
+    grids = import_or_fatal(grid_package)
+
+    if args.grid is not None:
+        grid_filename = args.grid.replace('.', '/') + '.py'
+        grid_file = Path(grids.__file__).parent / grid_filename
     if args.grid is None or not grid_file.exists():
         candidates = []
-        for info in pkgutil.walk_packages([Path(grids.__file__).parent]):
-            if not info.name.startswith('_'):
-                candidates.append(info.name)
-        if not grid_file.exists():
-            log(f'No grid file {grid_file.name} in package {root_name}. '
+        pkg_root = Path(grids.__file__).parent
+        for root, folders, files in os.walk(pkg_root):
+            for file in files:
+                fullpath = (Path(root) / file).relative_to(pkg_root)
+                if fullpath.name.endswith('.py') and not fullpath.name.startswith('_'):
+                    fullpath = fullpath.parent / fullpath.stem
+                    candidates.append(str(fullpath).replace('/', '.'))
+        if args.grid is not None and not grid_file.exists():
+            log(f'No grid file {grid_filename} in package {grid_package}. '
                 'Maybe you made a typo?')
         log(f"Potential grids are: {', '.join(candidates)}")
         sys.exit(0)
 
-    grid_name = root_name + "." + args.grid
+    grid_name = grid_package + "." + args.grid
     grid = import_or_fatal(grid_name)
 
     try:
@@ -120,7 +127,7 @@ def _get_explore(args):
 
 
 def grid_action(args: tp.Any, main: DecoratedMain):
-    explorer = _get_explore(args)
+    explorer = _get_explore(args, main)
     slurm = main.get_slurm_config()
     update_from_args(slurm, args)
     rules = SubmitRules()
@@ -156,7 +163,7 @@ def run_grid(main: DecoratedMain, explorer: Explorer, grid_name: str,
     if slurm is None:
         slurm = main.get_slurm_config()
 
-    grid_folder = main.dora.dir / main.dora.grids / grid_name
+    grid_folder = main.dora.dir / main.dora._grids / grid_name
     grid_folder.mkdir(exist_ok=True, parents=True)
 
     herd = Herd()
@@ -205,8 +212,9 @@ def run_grid(main: DecoratedMain, explorer: Explorer, grid_name: str,
                 log(f"Error when trying to load old sheep {child.name}: {error}")
                 # We fallback on manually loading the job file.
                 job_file = child / main.dora.shep.job_file
-                job = try_load(job_file)
-                if job is not None:
+                jobs = try_load(job_file)
+                if jobs is not None:
+                    job = jobs[0]
                     log(f"Canceling job {job.job_id} from unloadable sheep {child.name}.")
                     shepherd.cancel_lazy(job)
             else:
@@ -250,7 +258,7 @@ def run_grid(main: DecoratedMain, explorer: Explorer, grid_name: str,
         for sheep in sheeps:
             link = (grid_folder / sheep.xp.sig)
             if link.exists() or link.is_symlink():
-                assert link.is_symlink() and link.resolve() == sheep.xp.folder
+                assert link.is_symlink() and link.resolve() == sheep.xp.folder.resolve()
             else:
                 link.symlink_to(sheep.xp.folder)
 
