@@ -33,10 +33,11 @@ logger = logging.getLogger(__name__)
 
 class _SubmitItTarget:
     def __call__(self, main: DecoratedMain, argv: tp.Sequence[str]):
-        spec = get_distrib_spec()
-        os.environ['RANK'] = str(spec.rank)
-        os.environ['WORLD_SIZE'] = str(spec.world_size)
         self.xp = main.get_xp(argv)
+        spec = get_distrib_spec()
+        # We export the RANK as it can be used to customize logging early on
+        # in the called program (e.g. using Hydra).
+        os.environ['RANK'] = str(spec.rank)
         sys.argv[1:] = argv
         main()
 
@@ -203,7 +204,8 @@ class Shepherd:
                 if rules.replace_done:
                     logger.debug(f"Ignoring previously completed job {sheep.job.job_id}")
                     sheep.job = None
-            elif state in ["FAILED", "CANCELLED", "OUT_OF_MEMORY", "TIMEOUT", "MISSING"]:
+            elif state in ["FAILED", "CANCELLED", "OUT_OF_MEMORY", "TIMEOUT", "MISSING",
+                           "NODE_FAIL"]:
                 logger.debug(f"Previous job {sheep.job.job_id} failed or was canceled")
                 if rules.retry:
                     sheep.job = None
@@ -271,8 +273,10 @@ class Shepherd:
         else:
             gpus_per_node = gpus
             kwargs['nodes'] = 1
-        mem = slurm_config.mem_per_gpu * gpus_per_node
-        kwargs['mem'] = f"{mem}GB"
+        mem_per_gpu = slurm_config.mem_per_gpu
+        if mem_per_gpu:
+            mem = slurm_config.mem_per_gpu * gpus_per_node
+            kwargs['mem'] = f"{mem}GB"
         if slurm_config.one_task_per_node:
             kwargs['gpus_per_task'] = gpus_per_node
             kwargs['ntasks_per_node'] = 1
